==> 20250920-014506-1758357906-16.0.40.13-1392930350.tar.gz: files/tmp/qxact_reports_dump/qxact_reports.sql <==
-- MySQL dump 10.14  Distrib 5.5.65-MariaDB, for Linux (x86_64)
--
-- Host: localhost    Database: asterisk
-- ------------------------------------------------------
-- Server version	5.5.65-MariaDB

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `qxact_calls`
--

DROP TABLE IF EXISTS `qxact_calls`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `qxact_calls` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `time` int(10) unsigned DEFAULT NULL,
  `uniqueid` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `queuename` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `agent` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `event` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `callerid` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `waittime` smallint(5) unsigned NOT NULL DEFAULT '0',
  `calltime` int(10) unsigned NOT NULL DEFAULT '0',
  `origpos` smallint(5) unsigned NOT NULL DEFAULT '0',
  `position` int(10) unsigned NOT NULL DEFAULT '0',
  `did` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `key` tinyint(1) NOT NULL DEFAULT '-1',
  PRIMARY KEY (`id`),
  KEY `uniqueid_index` (`uniqueid`),
  KEY `queuename_index` (`queuename`),
  KEY `agent_index` (`agent`),
  KEY `event_index` (`event`),
  KEY `waittime_index` (`waittime`),
  KEY `calltime_index` (`calltime`),
  KEY `time_index` (`time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `qxact_calls`
--

LOCK TABLES `qxact_calls` WRITE;
/*!40000 ALTER TABLE `qxact_calls` DISABLE KEYS */;
/*!40000 ALTER TABLE `qxact_calls` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `qxact_agent_calls`
--

DROP TABLE IF EXISTS `qxact_agent_calls`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `qxact_agent_calls` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `time` int(10) unsigned DEFAULT NULL,
  `uniqueid` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `queuename` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `agent` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `event` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `ringtime` smallint(5) unsigned DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `time_index` (`time`),
  KEY `uniqueid_index` (`uniqueid`),
  KEY `queuename_index` (`queuename`),
  KEY `agent_index` (`agent`),
  KEY `event_index` (`event`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `qxact_agent_calls`
--

LOCK TABLES `qxact_agent_calls` WRITE;
/*!40000 ALTER TABLE `qxact_agent_calls` DISABLE KEYS */;
/*!40000 ALTER TABLE `qxact_agent_calls` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `qxact_agent_actions`
--

DROP TABLE IF EXISTS `qxact_agent_actions`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `qxact_agent_actions` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `time` int(10) unsigned DEFAULT NULL,
  `uniqueid` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `queuename` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `agent` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `event` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `channel` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `extension` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `logintime` int(10) unsigned NOT NULL DEFAULT '0',
  `reason` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (`id`),
  KEY `time_index` (`time`),
  KEY `agent_index` (`agent`),
  KEY `queuename_index` (`queuename`),
  KEY `event_index` (`event`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `qxact_agent_actions`
--

LOCK TABLES `qxact_agent_actions` WRITE;
/*!40000 ALTER TABLE `qxact_agent_actions` DISABLE KEYS */;
/*!40000 ALTER TABLE `qxact_agent_actions` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `qxact_system_events`
--

DROP TABLE IF EXISTS `qxact_system_events`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `qxact_system_events` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `time` int(10) unsigned DEFAULT NULL,
  `queuename` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `event` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (`id`),
  KEY `time_index` (`time`),
  KEY `queuename_index` (`queuename`),
  KEY `event_index` (`event`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `qxact_system_events`
--

LOCK TABLES `qxact_system_events` WRITE;
/*!40000 ALTER TABLE `qxact_system_events` DISABLE KEYS */;
/*!40000 ALTER TABLE `qxact_system_events` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `qxact_reports`
--

DROP TABLE IF EXISTS `qxact_reports`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `qxact_reports` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(256) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT 'UNNAMED REPORT',
  `data` longtext COLLATE utf8mb4_unicode_ci,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `qxact_reports`
--

LOCK TABLES `qxact_reports` WRITE;
/*!40000 ALTER TABLE `qxact_reports` DISABLE KEYS */;
/*!40000 ALTER TABLE `qxact_reports` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `qxact_reports_scheduler`
--

DROP TABLE IF EXISTS `qxact_reports_scheduler`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `qxact_reports_scheduler` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(256) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT 'UNNAMED REPORT',
  `data` longtext COLLATE utf8mb4_unicode_ci NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `qxact_reports_scheduler`
--

LOCK TABLES `qxact_reports_scheduler` WRITE;
/*!40000 ALTER TABLE `qxact_reports_scheduler` DISABLE KEYS */;
/*!40000 ALTER TABLE `qxact_reports_scheduler` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2025-09-20  1:45:51

==> 20251022-224840-1761198520-17.0.21.2-873851425.tar.gz: files/tmp/qxact_reports_dump/qxact_reports.sql <==
/*M!999999\- enable the sandbox mode */ 
-- MariaDB dump 10.19  Distrib 10.11.14-MariaDB, for debian-linux-gnu (x86_64)
--
-- Host: localhost    Database: asterisk
-- ------------------------------------------------------
-- Server version	10.11.14-MariaDB-0+deb12u2

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8mb4 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `qxact_calls`
--

DROP TABLE IF EXISTS `qxact_calls`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8mb4 */;
CREATE TABLE `qxact_calls` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `time` int(10) unsigned DEFAULT NULL,
  `uniqueid` varchar(32) NOT NULL DEFAULT '',
  `queuename` varchar(32) NOT NULL DEFAULT '',
  `agent` varchar(32) NOT NULL DEFAULT '',
  `event` varchar(32) NOT NULL DEFAULT '',
  `callerid` varchar(32) NOT NULL DEFAULT '',
  `waittime` smallint(5) unsigned NOT NULL DEFAULT 0,
  `calltime` int(10) unsigned NOT NULL DEFAULT 0,
  `origpos` smallint(5) unsigned NOT NULL DEFAULT 0,
  `position` int(10) unsigned NOT NULL DEFAULT 0,
  `did` varchar(32) NOT NULL DEFAULT '',
  `key` tinyint(1) NOT NULL DEFAULT -1,
  PRIMARY KEY (`id`),
  KEY `uniqueid_index` (`uniqueid`),
  KEY `queuename_index` (`queuename`),
  KEY `agent_index` (`agent`),
  KEY `event_index` (`event`),
  KEY `waittime_index` (`waittime`),
  KEY `calltime_index` (`calltime`),
  KEY `time_index` (`time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COLLATE=utf8mb3_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `qxact_calls`
--

LOCK TABLES `qxact_calls` WRITE;
/*!40000 ALTER TABLE `qxact_calls` DISABLE KEYS */;
/*!40000 ALTER TABLE `qxact_calls` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `qxact_agent_calls`
--

DROP TABLE IF EXISTS `qxact_agent_calls`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8mb4 */;
CREATE TABLE `qxact_agent_calls` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `time` int(10) unsigned DEFAULT NULL,
  `uniqueid` varchar(32) NOT NULL DEFAULT '',
  `queuename` varchar(32) NOT NULL DEFAULT '',
  `agent` varchar(32) NOT NULL DEFAULT '',
  `event` varchar(32) NOT NULL DEFAULT '',
  `ringtime` smallint(5) unsigned DEFAULT 0,
  PRIMARY KEY (`id`),
  KEY `time_index` (`time`),
  KEY `uniqueid_index` (`uniqueid`),
  KEY `queuename_index` (`queuename`),
  KEY `agent_index` (`agent`),
  KEY `event_index` (`event`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COLLATE=utf8mb3_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `qxact_agent_calls`
--

LOCK TABLES `qxact_agent_calls` WRITE;
/*!40000 ALTER TABLE `qxact_agent_calls` DISABLE KEYS */;
/*!40000 ALTER TABLE `qxact_agent_calls` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `qxact_agent_actions`
--

DROP TABLE IF EXISTS `qxact_agent_actions`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8mb4 */;
CREATE TABLE `qxact_agent_actions` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `time` int(10) unsigned DEFAULT NULL,
  `uniqueid` varchar(32) NOT NULL DEFAULT '',
  `queuename` varchar(32) NOT NULL DEFAULT '',
  `agent` varchar(32) NOT NULL DEFAULT '',
  `event` varchar(32) NOT NULL DEFAULT '',
  `channel` varchar(32) NOT NULL DEFAULT '',
  `extension` varchar(64) NOT NULL DEFAULT '',
  `logintime` int(10) unsigned NOT NULL DEFAULT 0,
  `reason` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`),
  KEY `time_index` (`time`),
  KEY `agent_index` (`agent`),
  KEY `queuename_index` (`queuename`),
  KEY `event_index` (`event`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COLLATE=utf8mb3_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `qxact_agent_actions`
--

LOCK TABLES `qxact_agent_actions` WRITE;
/*!40000 ALTER TABLE `qxact_agent_actions` DISABLE KEYS */;
/*!40000 ALTER TABLE `qxact_agent_actions` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `qxact_system_events`
--

DROP TABLE IF EXISTS `qxact_system_events`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8mb4 */;
CREATE TABLE `qxact_system_events` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `time` int(10) unsigned DEFAULT NULL,
  `queuename` varchar(32) NOT NULL DEFAULT '',
  `event` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`),
  KEY `time_index` (`time`),
  KEY `queuename_index` (`queuename`),
  KEY `event_index` (`event`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COLLATE=utf8mb3_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `qxact_system_events`
--

LOCK TABLES `qxact_system_events` WRITE;
/*!40000 ALTER TABLE `qxact_system_events` DISABLE KEYS */;
/*!40000 ALTER TABLE `qxact_system_events` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `qxact_reports`
--

DROP TABLE IF EXISTS `qxact_reports`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8mb4 */;
CREATE TABLE `qxact_reports` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(256) NOT NULL DEFAULT 'UNNAMED REPORT',
  `data` longtext DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COLLATE=utf8mb3_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `qxact_reports`
--

LOCK TABLES `qxact_reports` WRITE;
/*!40000 ALTER TABLE `qxact_reports` DISABLE KEYS */;
/*!40000 ALTER TABLE `qxact_reports` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `qxact_reports_scheduler`
--

DROP TABLE IF EXISTS `qxact_reports_scheduler`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8mb4 */;
CREATE TABLE `qxact_reports_scheduler` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(256) NOT NULL DEFAULT 'UNNAMED REPORT',
  `data` longtext NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COLLATE=utf8mb3_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `qxact_reports_scheduler`
--

LOCK TABLES `qxact_reports_scheduler` WRITE;
/*!40000 ALTER TABLE `qxact_reports_scheduler` DISABLE KEYS */;
/*!40000 ALTER TABLE `qxact_reports_scheduler` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2025-10-22 22:50:59
